function GradBaCo=GradBaCo(q,me)
  % Computes gradiants of barycentric coordinates on all d-simplices by using sparse matrices
  % d-simplex in R^n (d<=n)
  % returns a nme-by-(d+1)-by-n array.
  [n,d,nq,nme]=fc_meshtools.simplicial.get_dims(q,me);
  At=zeros(d,n,nme);I=zeros(d,n,nme);J=zeros(d,n,nme);
  L=0:(nme-1);
  for i=1:d 
    At(i,:,:)=q(:,me(i+1,:))-q(:,me(1,:));
    I(i,:,:)=repmat(L*d+i,[n,1]);
    for j=1:n
      J(i,j,:)=L*n+j;
    end
  end
  spAt=sparse(I(:),J(:),At(:),d*nme,n*nme);
  spH=spAt*spAt';
  Grad=[-ones(d,1),eye(d)];
  b=repmat(Grad,nme,1);
  X=spH\b;
  GradBaCo=spAt'*X;
  GradBaCo=reshape(GradBaCo,[n,nme,d+1]); % dimension n-by-nme-by-(d+1)
  GradBaCo=permute(GradBaCo,[2,3,1]); % dimension nme-by-(d+1)-by-n
  %GradBaCo=permute(GradBaCo,[2,1,3]); % dimension nme-by-n-by-(d+1)
end 

